@@ -1,5 +1,5 @@
-from biz import (BizService,)
-from card import (CardService,)
+from .biz import BizService
+from .card import CardService
 # import biz
 # import card
 NAME = "pyiikoapi"
